@@ -155,16 +155,16 @@ class Checker(object, metaclass=abc.ABCMeta):
                 omitted_int_conv_ok=d.omitted_int_conv_ok,
             )
 
-    def check_msgids(self, message, msgid_formats):
-        pass
+    def check_msgids(self, message, msgid_fmts):
+        pass  # no coverage
 
     @abc.abstractmethod
     def check_string(self, ctx, message, s):
-        return
+        pass  # no coverage
 
     @abc.abstractmethod
     def check_args(self, message, src_loc, src_fmt, dst_loc, dst_fmt, *, omitted_int_conv_ok=False):
-        return
+        pass  # no coverage
 
 __all__ = ['Checker']
 
