@@ -39,7 +39,7 @@ from lib import paths as pathmod
 from lib import tags
 from lib import terminal
 
-__version__ = '0.25.2'
+__version__ = '0.25.4'
 
 def initialize_terminal():
     if sys.stdout.isatty():
@@ -157,7 +157,7 @@ parse_jobs.__name__ = 'jobs'
 class VersionAction(argparse.Action):
 
     def __init__(self, option_strings, dest=argparse.SUPPRESS):
-        super(VersionAction, self).__init__(
+        super().__init__(
             option_strings=option_strings,
             dest=dest,
             nargs=0,
