@@ -18,6 +18,9 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+import lib.encodings
+import lib.ling
+
 import nose
 from nose.tools import (
     assert_equal,
@@ -34,9 +37,6 @@ from nose.tools import (
 
 from . import tools
 
-import lib.encodings
-import lib.ling
-
 L = lib.ling
 T = lib.ling.Language
 E = lib.encodings
@@ -79,8 +79,8 @@ class test_fix_codes:
 def test_language_repr():
     # Language.__repr__() is never used by i18nspector itself,
     # but it's useful for debugging test failures.
-    l = T('el')
-    assert_equal(repr(l), '<Language el>')
+    lng = T('el')
+    assert_equal(repr(lng), '<Language el>')
 
 class test_language_equality:
 
